@@ -2,7 +2,7 @@ package Datahub::Factory::Importer::KMSKA;
 
 use Datahub::Factory::Sane;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Moo;
 use Catmandu;
@@ -153,7 +153,7 @@ sub __subjects {
 
 sub __objtitles {
     my $self = shift;
-    $self->merge_call('SELECT * FROM vobjtitles', 'objtitles', 'objtitles');
+    $self->prepare_call('SELECT * FROM vobjtitles', 'objtitles', 'objtitles');
 }
 
 1;
